@@ -5,8 +5,12 @@ setMethod("call.estimate", signature(object="Confint"),
            function(object) object@call.estimate)
 setMethod("name.estimate", signature(object="Confint"),
            function(object) object@name.estimate)
+setMethod("completecases.estimate", signature(object="Confint"),
+           function(object) object@completecases.estimate)
 setMethod("samplesize.estimate", signature(object="Confint"),
-           function(object) object@samplesize.estimate)
+           function(object, onlycompletecases = TRUE)
+  	    (object@samplesize.estimate+
+  	     (1-onlycompletecases)*sum(object@completecases.estimate==FALSE)))
 setMethod("nuisance.estimate", signature(object="Confint"),
            function(object) object@nuisance.estimate)
 setMethod("trafo.estimate", signature(object="Confint"),
@@ -16,3 +20,5 @@ setMethod("fixed.estimate", signature(object="Confint"),
 setMethod("type", signature(object="Confint"),
            function(object) object@type)
 
+
+
